.. image:: https://travis-ci.com/pakal/compat-patcher-core.svg?branch=master
    :target: https://travis-ci.com/pakal/compat-patcher-core


=====================
compat-patcher-core
=====================

    *Because Compatibility Matters*

Welcome to Compat Patcher Core, a mini-framework to build "Compatibility Patchers", i.e companion applications which
allow your favorite frameworks/libraries to keep long term API stability, while still getting new features at a good pace.

Documentation available on `Read The Docs <https://compat-patcher-core.readthedocs.io/en/latest/index.html>`_!


Which applications currently benefit from this system?

- `Django via Django-Compat-Patcher <https://github.com/pakal/django-compat-patcher>`_
